@@ -278,6 +278,19 @@ namespace number_tests {
     TEST_SUCCEED();
   }
 
+  bool issue2099() {
+    TEST_START();
+    ondemand::parser parser;
+    auto json = "1000000000.000000001"_padded;
+    ondemand::document doc;
+    ASSERT_SUCCESS(parser.iterate(json).get(doc));
+    ondemand::number number;
+    ASSERT_SUCCESS(doc.get_number().get(number));
+    ASSERT_EQUAL(number.get_number_type(), ondemand::number_type::floating_point_number);
+    ASSERT_EQUAL(number.get_double(), 1e9);
+    TEST_SUCCEED();
+}
+
   bool issue1878() {
     TEST_START();
     ondemand::parser parser;
@@ -391,6 +404,7 @@ namespace number_tests {
 
     TEST_SUCCEED();
   }
+
   bool issue2017() {
     TEST_START();
     ondemand::parser parser;
@@ -403,8 +417,35 @@ namespace number_tests {
     TEST_SUCCEED();
   }
 
+  bool issue2045() {
+    TEST_START();
+    ondemand::parser parser;
+    ondemand::document doc;
+    padded_string docdata = R"(-18446744073709551615)"_padded;
+    ASSERT_SUCCESS(parser.iterate(docdata).get(doc));
+    int64_t bigint;
+    ASSERT_ERROR(doc.get_int64().get(bigint), INCORRECT_TYPE);
+    TEST_SUCCEED();
+  }
+
+
+  bool issue2093() {
+    TEST_START();
+    ondemand::parser parser;
+    ondemand::document doc;
+    padded_string docdata = R"(0.95000000000000000000)"_padded;
+    ASSERT_SUCCESS(parser.iterate(docdata).get(doc));
+    double d;
+    ASSERT_SUCCESS(doc.get_double().get(d));
+    ASSERT_EQUAL(d, 0.95);
+    TEST_SUCCEED();
+  }
+
   bool run() {
-    return issue2017() &&
+    return issue2099() &&
+           issue2093() &&
+           issue2045() &&
+           issue2017() &&
            issue_1898() &&
            issue1878() &&
            get_root_number_tests() &&
