@@ -18,7 +18,7 @@ namespace scalar_tests {
   bool test_scalar_value(const padded_string &json, const T &expected, bool test_twice=true) {
     std::cout << "- JSON: " << json << endl;
     SUBTEST( "simdjson_result<document>", test_ondemand_doc(json, [&](auto doc_result) {
-      T actual;
+      T actual{};
       ASSERT_RESULT( doc_result.type(), expected_json_type<T>() );
       ASSERT_SUCCESS( doc_result.get(actual) );
       ASSERT_EQUAL( actual, expected );
@@ -33,7 +33,7 @@ namespace scalar_tests {
     SUBTEST( "document", test_ondemand_doc(json, [&](auto doc_result) {
       ondemand::document doc;
       ASSERT_SUCCESS( std::move(doc_result).get(doc) );
-      T actual;
+      T actual{};
       ASSERT_RESULT( doc.type(), expected_json_type<T>() );
       ASSERT_SUCCESS( doc.get(actual) );
       ASSERT_EQUAL( actual, expected );
@@ -50,7 +50,7 @@ namespace scalar_tests {
       padded_string whitespace_json = std::string(json) + " ";
       std::cout << "- JSON: " << whitespace_json << endl;
       SUBTEST( "simdjson_result<document>", test_ondemand_doc(whitespace_json, [&](auto doc_result) {
-        T actual;
+        T actual{};
         ASSERT_RESULT( doc_result.type(), expected_json_type<T>() );
         ASSERT_SUCCESS( doc_result.get(actual) );
         ASSERT_EQUAL( actual, expected );
@@ -65,7 +65,7 @@ namespace scalar_tests {
       SUBTEST( "document", test_ondemand_doc(whitespace_json, [&](auto doc_result) {
         ondemand::document doc;
         ASSERT_SUCCESS( std::move(doc_result).get(doc) );
-        T actual;
+        T actual{};
         ASSERT_RESULT( doc.type(), expected_json_type<T>() );
         ASSERT_SUCCESS( doc.get(actual) );
         ASSERT_EQUAL( actual, expected );
@@ -85,7 +85,7 @@ namespace scalar_tests {
       SUBTEST( "simdjson_result<value>", test_ondemand_doc(array_json, [&](auto doc_result) {
         int count = 0;
         for (simdjson_result<ondemand::value> val_result : doc_result) {
-          T actual;
+          T actual{};
           ASSERT_RESULT( val_result.type(), expected_json_type<T>() );
           ASSERT_SUCCESS( val_result.get(actual) );
           ASSERT_EQUAL(actual, expected);
@@ -105,7 +105,7 @@ namespace scalar_tests {
         for (simdjson_result<ondemand::value> val_result : doc_result) {
           ondemand::value val;
           ASSERT_SUCCESS( val_result.get(val) );
-          T actual;
+          T actual{};
           ASSERT_RESULT( val.type(), expected_json_type<T>() );
           ASSERT_SUCCESS( val.get(actual) );
           ASSERT_EQUAL(actual, expected);
@@ -129,7 +129,7 @@ namespace scalar_tests {
       SUBTEST( "simdjson_result<value>", test_ondemand_doc(whitespace_array_json, [&](auto doc_result) {
         int count = 0;
         for (simdjson_result<ondemand::value> val_result : doc_result) {
-          T actual;
+          T actual{};
           ASSERT_RESULT( val_result.type(), expected_json_type<T>() );
           ASSERT_SUCCESS( val_result.get(actual) );
           ASSERT_EQUAL(actual, expected);
@@ -150,7 +150,7 @@ namespace scalar_tests {
         for (simdjson_result<ondemand::value> val_result : doc_result) {
           ondemand::value val;
           ASSERT_SUCCESS( val_result.get(val) );
-          T actual;
+          T actual{};
           ASSERT_RESULT( val.type(), expected_json_type<T>() );
           ASSERT_SUCCESS( val.get(actual) );
           ASSERT_EQUAL(actual, expected);
@@ -297,8 +297,92 @@ namespace scalar_tests {
 
 #endif // SIMDJSON_EXCEPTIONS
 
+  bool string_with_trailing() {
+    TEST_START();
+    auto json = R"( "a string" badstuff )"_padded;
+    ondemand::parser parser;
+    ondemand::document doc;
+    ASSERT_SUCCESS(parser.iterate(json).get(doc));
+    std::string_view view;
+    ASSERT_ERROR(doc.get_string().get(view), TRAILING_CONTENT);
+    TEST_SUCCEED();
+  }
+
+  bool uint64_with_trailing() {
+    TEST_START();
+    auto json = R"( 133 badstuff )"_padded;
+    ondemand::parser parser;
+    ondemand::document doc;
+    ASSERT_SUCCESS(parser.iterate(json).get(doc));
+    uint64_t x;
+    ASSERT_ERROR(doc.get_uint64().get(x), TRAILING_CONTENT);
+    TEST_SUCCEED();
+  }
+
+  bool int64_with_trailing() {
+    TEST_START();
+    auto json = R"( 133 badstuff )"_padded;
+    ondemand::parser parser;
+    ondemand::document doc;
+    ASSERT_SUCCESS(parser.iterate(json).get(doc));
+    int64_t x;
+    ASSERT_ERROR(doc.get_int64().get(x), TRAILING_CONTENT);
+    TEST_SUCCEED();
+  }
+
+  bool double_with_trailing() {
+    TEST_START();
+    auto json = R"( 133 badstuff )"_padded;
+    ondemand::parser parser;
+    ondemand::document doc;
+    ASSERT_SUCCESS(parser.iterate(json).get(doc));
+    double x;
+    ASSERT_ERROR(doc.get_double().get(x), TRAILING_CONTENT);
+    TEST_SUCCEED();
+  }
+
+
+  bool bool_with_trailing() {
+    TEST_START();
+    auto json = R"( true badstuff )"_padded;
+    ondemand::parser parser;
+    ondemand::document doc;
+    ASSERT_SUCCESS(parser.iterate(json).get(doc));
+    bool x;
+    ASSERT_ERROR(doc.get_bool().get(x), TRAILING_CONTENT);
+    TEST_SUCCEED();
+  }
+
+  bool null_with_trailing() {
+    TEST_START();
+    auto json = R"( null badstuff )"_padded;
+    ondemand::parser parser;
+    ondemand::document doc;
+    ASSERT_SUCCESS(parser.iterate(json).get(doc));
+    ASSERT_ERROR(doc.is_null(), TRAILING_CONTENT);
+    TEST_SUCCEED();
+  }
+
+  bool nully() {
+    TEST_START();
+    auto json = R"( nully )"_padded;
+    ondemand::parser parser;
+    ondemand::document doc;
+    ASSERT_SUCCESS(parser.iterate(json).get(doc));
+    bool x;
+    ASSERT_SUCCESS(doc.is_null().get(x));
+    ASSERT_TRUE(!x);
+    TEST_SUCCEED();
+  }
+
   bool run() {
     return
+           nully() &&
+           string_with_trailing() &&
+           uint64_with_trailing() &&
+           int64_with_trailing() &&
+           bool_with_trailing() &&
+           null_with_trailing() &&
            string_value() &&
            numeric_values() &&
            boolean_values() &&
